package RFC::Prototype::208;

use strict;
use base qw(Exporter);
use vars qw(@EXPORT $LAST_SALT);
@EXPORT = qw(crypt);


sub crypt ($;$) {
    my($text) = shift;
    my $salt;

    if( @_ ) {
        $salt = shift;
    }
    else {
        $salt = join '', ('.', '/', 0..9, 
                          'A'..'Z', 'a'..'z')[rand 64, rand 64];
    }

    # Useful for testing.
    $LAST_SALT = $salt;

    return CORE::crypt($text, $salt);
}


=pod

=head1 NAME

RFC::Prototype::208 - crypt() default salt

=head1 SYNOPSIS

    use RFC::Prototype::208;

    $crypted = crypt($text);


=head1 DESCRIPTION

This is a prototype implementation of perl 6 RFC 208


=head1 CAVEATS

This assumes only the standard DES crypt, it doesn't yet take into
account MD5 or other crypting systems.


=head1 AUTHOR

Michael G Schwern <schwern@pobox.com>


=head1 SEE ALSO

RFC 208 - http://dev.perl.org/rfc/208.pod, L<crypt(3)>, L<perlfunc>

=cut

1;
